@@ -84,8 +84,9 @@ class BaseTestCase(base.BaseTestCase):
         to_exec = []
         # Make all requests as a noauth admin user.
         to_exec += [
-            '--os-url', self.placement.endpoint,
+            '--os-endpoint', self.placement.endpoint,
             '--os-token', self.placement.token,
+            '--os-auth-type', 'admin_token',
         ]
         if self.VERSION is not None:
             to_exec += ['--os-placement-api-version', self.VERSION]
@@ -242,6 +243,33 @@ class BaseTestCase(base.BaseTestCase):
 
         return result
 
+    def resource_allocation_unset(self, consumer_uuid, provider=None,
+                                  use_json=True):
+        if provider:
+            # --provider can be specified multiple times so if we only get
+            # a single string value convert to a list.
+            if isinstance(provider, six.string_types):
+                provider = [provider]
+            cmd = 'resource provider allocation unset %s %s' % (
+                ' '.join('--provider %s' %
+                         rp_uuid for rp_uuid in provider),
+                consumer_uuid
+            )
+        else:
+            cmd = 'resource provider allocation unset %s' % consumer_uuid
+        result = self.openstack(cmd, use_json=use_json)
+
+        def cleanup(uuid):
+            try:
+                self.openstack('resource provider allocation delete ' + uuid)
+            except CommandException as exc:
+                # may have already been deleted by a test case
+                if 'not found' in six.text_type(exc).lower():
+                    pass
+        self.addCleanup(cleanup, consumer_uuid)
+
+        return result
+
     def resource_allocation_delete(self, consumer_uuid):
         cmd = 'resource provider allocation delete ' + consumer_uuid
         return self.openstack(cmd)
@@ -262,10 +290,19 @@ class BaseTestCase(base.BaseTestCase):
             cmd += ' --resource-class ' + resource_class
         self.openstack(cmd)
 
-    def resource_inventory_set(self, uuid, *resources):
-        cmd = 'resource provider inventory set {uuid} {resources}'.format(
-            uuid=uuid, resources=' '.join(
-                ['--resource %s' % r for r in resources]))
+    def resource_inventory_set(self, uuid, *resources, **kwargs):
+        opts = []
+        if kwargs.get('aggregate'):
+            opts.append('--aggregate')
+        if kwargs.get('amend'):
+            opts.append('--amend')
+        if kwargs.get('dry_run'):
+            opts.append('--dry-run')
+        fmt = 'resource provider inventory set {uuid} {resources} {opts}'
+        cmd = fmt.format(
+            uuid=uuid,
+            resources=' '.join(['--resource %s' % r for r in resources]),
+            opts=' '.join(opts))
         return self.openstack(cmd, use_json=True)
 
     def resource_inventory_class_set(self, uuid, resource_class, **kwargs):
